# Automata Fees

## Packaging
`python3 -m build`

## Dependencies (IDE Terminal)
`pip install persuader-technology-automata-redis`

## Requires 

### Options
* ACCOUNT_TRADE_FEE_KEY
* INSTRUMENT_TRADE_FEE_KEY - format value "{instrument}" to the correct value
